<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Carbon\Carbon;
use App\Client;
use App\Meta;
use App\Atendimento;
use App\User;
use App\Zonas;
use DB;
use Session;
use Auth;
use Illuminate\Support\Facades\DB as FacadesDB;
use Redirect;

class ClientesController extends Controller
{

    public function index(){
        if(Auth::user()->perfil == 2){
            $clients = Client::with('acompanhante')->where('cabo_id', Auth::user()->id)->where('status', 1)->get();
        }
        else{
            $clients = Client::with('acompanhante')->where('status', 1)->get();
        }
        $clientes_whats = Client::select('*', 'phone as telefone')
        ->where('phone','!=', 'NULL')
        ->where('phone','!=', "Número inválido")
        ->where('status', 1)

        ->where('is_checked', 0)->get();

        return view('clientes.show', compact('clients', 'clientes_whats'));
    }

    public function create(){
        $zonas = Zonas::where('status', 1)->orderBy('zona', 'asc')->get();
        return view('clientes.create',  compact('zonas'));
    }

    public function importar(){
        return view('clientes.importar');
    }

    public function storeImportacao(Request $request){
        if ($request->hasFile('planilha') && $request->file('planilha')->isValid()) {
            $image = $request->file('planilha');
            $image->move('csv/', 'produtosImportacao.' . $image->getClientOriginalExtension());
            $csvFileName = 'produtosImportacao.' . $image->getClientOriginalExtension();
            $csvFile = public_path('csv/' . $csvFileName);
            if ($this->readCSV($csvFile, array('delimiter' => ',')) == true) {
                Session::flash('flash_message', 'Planilha importada com sucesso!');
            } else {
                Session::flash('error', 'Falha! Tente novamente. Caso o erro continue entre em contato com o suporte.');
            }
            return redirect()->back();
        }
    }

    public function readCSV($csvFile, $array)
    {
        $file_handle = fopen($csvFile, 'r');
        while (!feof($file_handle)) {
            $line_of_text[] = fgetcsv($file_handle, 0, $array['delimiter']);
        }
       // dd($line_of_text);
        fclose($file_handle);
        $ordemSubgrupo = 1;
        $ordemProduto = 1;
        try {
            DB::beginTransaction();
            foreach ($line_of_text as $key => $line) {
                if ($key > 0 && $line[0]) {
                    //dd($line[1]);
                    $clienteExiste = Client::where("phone", $this->formatPhoneNumber($this->formatPhoneNumber($line[1])))->first();
                   // dd($clienteExiste);
                    if(!$clienteExiste){
                        DB::table('clients')->insert([

                            'name' => strtoupper(trim($line[0])),
                            'phone' => $this->formatPhoneNumber($line[1]),
                            'bairro' => trim($line[2]),

                        ]);
                    }
                    }

            }
            DB::commit();
            return true;
        } catch (\Throwable $th) {
            DB::rollBack();
            return false;
        }
    }

    public function details($id){
        $paciente = Client::find($id);
        $atendimentos = Atendimento::where('paciente_id', $id)->get();
        return view('atendimento.details',  compact('atendimentos', 'paciente'));
    }

    function formatPhoneNumber($number) {

        // Remove quaisquer caracteres não numéricos (por exemplo, hifens) do número
        $number = preg_replace('/\D/', '', $number);

        // Se o número tiver 11 dígitos, ele já inclui o DDD
        if (strlen($number) === 11) {
            $ddd = substr($number, 0, 2);
            $number = substr($number, 2);
        }
        // Se o número tiver 9 dígitos, presume-se que não tem DDD
        elseif (strlen($number) === 9) {
            $ddd = '73';
        }
        // Se o número tiver 8 dígitos, presume-se que não tem DDD e o número é fixo
        elseif (strlen($number) === 8) {
            $ddd = '73';
            $number = '9' . $number;
        }
        else {
            return 'Número inválido'; // Caso o número não corresponda a nenhum formato esperado
        }

        // Formata o número com o padrão esperado
        $formattedNumber = sprintf('(%s) %s-%s',
            $ddd,
            substr($number, 0, 5),
            substr($number, 5)
        );

        return $formattedNumber;
    }

    public function edit($id){
        $cliente = Client::find($id);
        $users = User::where('status', 1)->where('perfil', 2)->get();
        $zonas = Zonas::where('status', 1)->get();
        return view('clientes.edit', compact('cliente', 'users', 'zonas'));
    }

    public function store (Request $request) {
        try {
            $clientInput = $request->all();
            $clientCreated = false;
            $clientInput['cabo_id'] =  Auth::user()->id;
            $clientInput['nascimento'] = \str_replace('/', '-',$clientInput['nascimento']);
            $clientInput['nascimento'] = Carbon::parse( $clientInput['nascimento']);
            $clientCreated = Client::create($clientInput);

            if (Auth::user()->perfil == 2) {
                $checkMeta = Meta::where('date', date('Y-m-d'))->first();
                if ($checkMeta) {
                    $checkMeta->qtd = $checkMeta->qtd + 1;
                } else {
                    $checkMeta = new Meta;
                    $checkMeta->lideranca_id = Auth::user()->id;
                    $checkMeta->lideranca_nome = Auth::user()->name;
                    $checkMeta->date = date('Y-m-d');
                    $checkMeta->qtd = 1;
                    $checkMeta->tipo = 0;
                }
                $checkMeta->save();
            }

            if(!$request->ajax()){
                Session::flash('message', 'Cliente criado com sucesso!');
            }
        } catch (Throwable $e) {
            Session::flash('error', $e->getMessage());
        }
        if ($request->ajax()) {
            if ($clientCreated) {
                $clientCreated['nascimento'] = Carbon::parse($clientCreated['nascimento'])->format('d-m-Y');
                return response()->json($clientCreated);
            }
            else {
                return response()->json('existente', 500);
            }
        }else {
            return Redirect::to('clientes/create');
        }
    }

    public function update (Request $request){
        $input = $request->all();

        $input['nascimento'] = \str_replace('/', '-',$input['nascimento']);
        $input['nascimento'] = Carbon::parse( $input['nascimento']);
        try {
            Client::where('id','=',$input['id'])->update( array(
                'name' => $input['name'],
                'email' => $input['email'],
                'cpf' => $input['cpf'],
                'nascimento' => $input['nascimento'],
                'titulo' => $input['titulo'],
                'phone' => $input['phone'],
                'zona' => $input['zona'],
                'secao' => $input['secao'],
                'phone' => $input['phone'],
                'rua' => $input['rua'],
                'zona_regiao' => $input['zona_regiao'],
                'bairro' => $input['bairro'],
                'numero' => $input['numero'],
                'city' => $input['city'],
                'complemento' => $input['complemento'],
                'profissao' => $input['profissao'],
                'sus' => $input['sus']
            ));
        } catch (Throwable $e) {
            Session::flash('error', $e->getMessage());
        }

      return redirect()->route('clientes');
    }

    public function serverSide() {
        $client = Client::all();
    }

    public function destroy(Request $request) {
        Client::where('id', $request->clientId)->update([
            'status' => 0
        ]);
        return;
    }

    public function checkEmail (Request $request)
    {
        if (Client::where('email', $request->email)->first()) {
            return response()->json(true);
        } else {
            return response()->json(false);
        }
    }

    public function checkCPF (Request $request)
    {
        if (Client::where('cpf', $request->cpf)->first()) {
            return response()->json(true);
        } else {
            return response()->json(false);
        }
    }

    public function checkWhatsapp(Request $request)
    {
        $input = $request->all();
        if (Client::where('phone', $input['whatsapp'])->where('status', 1)->first()) {
            return response()->json(false);
        } else {
            return response()->json(true);
        }
    }

    function importContactWhatsappp(Request $request){
        $contacts = $request->all();

        $qtd = DB::Transaction(function() use($contacts) {
            $count = 0;

            foreach ($contacts as $contact) {
                //dd($contact);
                try {
                    if(isset($contact['name'])){
                        $nome =  $contact['name'] ? $contact['name']: ($contact['name'] != '' ?  $contact['name'] :  ($contact['shortName'] ? $contact['shortName']: ($contact['pushname'] ? $contact['pushname'] : ($contact['verifiedName']? $contact['verifiedName']: $contact['formattedName'] ))));
                        $clienteExiste = Client::where("phone", $this->formatPhoneNumberWhatsapp($contact["id"]["user"]))->first();
                        if(!$clienteExiste){
                            try {
                                if(!$this->contemCaracteresEspeciais($nome)){
                                    $cliente = Client::create([
                                        "name" => $nome,
                                        "phone" => $this->formatPhoneNumberWhatsapp($contact["id"]["user"]),
                                        "is_checked" => true,
                                        "w_contact" =>  $contact["id"]["_serialized"],
                                        "type_client" => 1,
                                    ]);
                                    $count ++;
                                }


                            } catch (\Throwable $th) {
                                throw $th;
                            }
                        }
                    }
                } catch (\Throwable $th) {
                    dd($contact);
                }


            }
            return  $count;
        }, 5);
        return response()->json($qtd);
    }

    function contemCaracteresEspeciais($nome) {
        return preg_match('/[+\(\)\-\d]/', $nome) === 1;
    }

    function formatPhoneNumberWhatsapp($internationalNumber) {

        $numberWithoutCountryCode = substr($internationalNumber, 2);


        $ddd = substr($numberWithoutCountryCode, 0, 2);
        $number = substr($numberWithoutCountryCode, 2);

        if (strlen($number) === 8) {
            $formattedNumber = sprintf('(%s) %s-%s',
                $ddd,
                substr($number, 0, 4),
                substr($number, 4)
            );
        } else {
            $formattedNumber = sprintf('(%s) %s-%s',
                $ddd,
                substr($number, 0, 5),
                substr($number, 5)
            );
        }

        return $formattedNumber;
    }

    function updateContactWhatsappp(Request $request){
        $contacts = $request->all();
        DB::Transaction(function() use($contacts) {
            foreach ($contacts as $contact) {
                try {
                    if(isset($contact["id"]["_serialized"])){
                        client::where('id', $contact["id_client"])
                        ->update([
                                'is_checked' => true,
                                'is_whatsapp' => $contact["numberExists"] == 'true' ? true : false,
                                'w_contact' => $contact["id"]["_serialized"],
                        ]);
                    }
                    else{
                        client::where('id', $contact["id_client"])
                        ->update([
                                'is_checked' => true,
                                'is_whatsapp' => false

                        ]);
                    }

                } catch (\Throwable $th) {

                }

            }
        }, 5);
        $clientes_whats = Client::select('*', 'phone as telefone')
        ->where('phone','!=', 'NULL')
        ->where('phone','!=', "Número inválido")
        ->where('status', 1)

        ->where('is_checked', 0)->get();
        return response()->json($clientes_whats);
    }
}
