<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Comunicacao;
use App\ComunicacaoPergunta;
use App\User;
use App\Client;
use Redirect;
use Session;
use Auth;
use Image;
use DB;

class ComunicacaoController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $comunicacoes = Comunicacao::with('pergunta')->get();
        $all_contacts = Client::where('status', 1)
        ->where('phone', "!=", "Número inválido")
        ->where('is_whatsapp', true)
        ->get();
        return view('comunicacoes.show', compact('comunicacoes' ,  'all_contacts'));
    }

    public function create()
    {
        return view('comunicacoes.create');
    }

    public function store(Request $request)
    {
        $input = $request->all();
        $input['responsavel'] = Auth::user()->name;
        $comunicacao = Comunicacao::create($input);
        if ($input['tipo_mensagem'] == 'Mensagem') {
            if ($request->hasFile('comunicacaoInputFile') && $request->file('comunicacaoInputFile')->isValid()) {
                $image = $request->file('comunicacaoInputFile');
                $img = Image::make($image->path());
                $url = 'comunicacao' . time() . '.' . $image->getClientOriginalExtension();
                $img->save('comunicacao/whatsapp/'.$url);
                $comunicacao->url = $url;
                $comunicacao->save();
                $configs = DB::table('configs')->first();
                return response()->json($this->sendWhatsapp($input['pessoa_enviar'], $input['tipo_mensagem'], $input['mensagem'], null,
                    'https://' . $configs->subdominio . '.bizybox.com.br/public/' . $url));
            } else {
                return response()->json('falha');
            }
        } else {
            if ($comunicacao) {
                $comunicacao->mensagem = $input['enquete'];
                $comunicacao->save();
                $perguntas = \json_decode($input['perguntas']);
                foreach ($perguntas as $key => $value) {
                    $pergunta = new ComunicacaoPergunta;
                    $pergunta->comunicacao_id = $comunicacao->id;
                    $pergunta->pergunta = $value->pergunta;
                    $pergunta->save();
                }
                return response()->json($this->sendWhatsapp($input['pessoa_enviar'], $input['tipo_mensagem'], $input['enquete'],
                $input['perguntas'], null));
            } else {
                return response()->json('falha');
            }
        }
    }

    public function sendWhatsapp($praQuem, $tipo, $mensagem, $perguntas, $urlImagem)
    {
        if ($praQuem == "Liderancas") {
            $result = User::where('status', '!=', 0)->where('id', '!=', 1)->pluck('whatsapp', 'name');
            $numeros = $this->formataTelefone($result);
        } else if ($praQuem == "Eleitores") {
            $result = Client::where('status', '!=', 0)->pluck('phone','name');
            $numeros = $this->formataTelefone($result);
        } else {
            $liderancasNumeros = User::where('status', '!=', 0)->where('id', '!=', 1)->pluck('whatsapp', 'name')->toArray();
            $eleitoresNumeros = Client::where('status', '!=', 0)->pluck('phone','name')->toArray();
            $result = array_merge($liderancasNumeros, $eleitoresNumeros);
            $numeros = $this->formataTelefone($result);
        }

        $objSend = new \stdClass();
        $objSend->numeros = $numeros;
        $objSend->mensagem = $mensagem;
        $objSend->url = $urlImagem;
        $objSend->perguntas = $perguntas;
        $objSend->tipo = $tipo;

        $objComunicacao = json_encode($objSend);

        return $objComunicacao;
    }

    public function formataTelefone($numeros)
    {
        $arrayWhatsapp = [];
        foreach ($numeros as $key => $value) {
            $arrayWhatsapp[$key] = preg_replace("/[^0-9]/", "", $value);
        }
        return $arrayWhatsapp;
    }

    public function destroy(Request $request)
    {
        $input = $request->all();
        Comunicacao::where('id', $input['comunicacaoId'])->delete();
        return;
    }

    public function config(){
        return view('comunicacoes.config');
    }

    public function getPromotion($id){
        $list =  Comunicacao::find($id);
        $list->imagem =  asset('comunicacao/whatsapp/'. $list->url);
        $list->titulo = 'Olá';
        $list->descricao =  $list->mensagem;
        $list->rodape = ' ';
        return response()->json($list);
    }
}
