<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use Session;
use DB;
use Auth;
use URL;
use Redirect;

use App\Occurrence;
use App\Configuration;
use App\OccurrenceType;
use App\AssessmentType;
use App\OccurrenceLocal;

class OccurrencesController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function show()
    {
        $data_base = date('Y-m-d');
        $date = date('d/m/Y');
        $data_inicial = date('Y-m-01', strtotime($data_base));
        $data_final = date('Y-m-t', strtotime($data_base));       
        
        $occurrences = Occurrence::where('created_at', '>=', $data_inicial.' 00:00:00')
            ->where('created_at', '<=',  $data_final.' 23:59:59')
            ->get();

        $occurrenceTotal = 0;
        $occurrenceTotal = count($occurrences);

        $occurrencesByAssessment = Occurrence::where('created_at', '>=', $data_inicial.' 00:00:00')
            ->where('created_at', '<=',  $data_final.' 23:59:59')
            ->select('assessment', DB::raw('count(*) as total'))
            ->groupBy('assessment')
            ->get();

        return view('occurrences.show', compact('occurrences', 'occurrencesByAssessment', 'occurrenceTotal' ,'date'));
    }

    public function getData(Request $request)
    {
        $input = $request->all();
        $periodo = explode("-", $input['periodo']);
        $periodo[0] = str_replace("/", "-", $periodo[0]);
        $periodo[1] = str_replace("/", "-", $periodo[1]);
        $data_inicial = date('Y-m-d 00:00:00', strtotime($periodo[0]));
        $data_final = date('Y-m-d 23:59:59', strtotime($periodo[1]));

        $occurrences = Occurrence::where('created_at', '>=', $data_inicial)
            ->where('created_at', '<=',  $data_final)
            ->get();

        $occurrenceTotal = 0;
        $occurrenceTotal = count($occurrences);

        $occurrencesByAssessment = Occurrence::where('created_at', '>=', $data_inicial)
            ->where('created_at', '<=',  $data_final)
            ->select('assessment', DB::raw('count(*) as total'))
            ->groupBy('assessment')
            ->get();

        return response()->json([$occurrences, $occurrencesByAssessment, $occurrenceTotal]);
    }

    public function getDataMobile(Request $request)
    {
        $input = $request->all();
        $periodo = explode("-", $input['periodo']);
        $periodo[0] = str_replace("/", "-", $periodo[0]);
        $periodo[1] = str_replace("/", "-", $periodo[1]);
        $data_inicial = date('Y-m-d 00:00:00', strtotime($periodo[0]));
        $data_final = date('Y-m-d 23:59:59', strtotime($periodo[1]));

        $occurrences = Occurrence::where('created_at', '>=', $data_inicial)
            ->where('created_at', '<=',  $data_final)
            ->where('user_id', Auth::id())
            ->get();

        $occurrenceTotal = 0;
        $occurrenceTotal = count($occurrences);

        $occurrencesByAssessment = Occurrence::where('created_at', '>=', $data_inicial)
            ->where('created_at', '<=',  $data_final)
            ->where('user_id', Auth::id())
            ->select('assessment', DB::raw('count(*) as total'))
            ->groupBy('assessment')
            ->get();

        return response()->json([$occurrences, $occurrencesByAssessment, $occurrenceTotal]);
    }

    public function myOccurrences()
    {
        $data_base = date('Y-m-d');
        $date = date('d/m/Y');
        $data_inicial = date('Y-m-01', strtotime($data_base));
        $data_final = date('Y-m-t', strtotime($data_base));       
        
        $occurrences = Occurrence::where('created_at', '>=', $data_inicial.' 00:00:00')
            ->where('created_at', '<=',  $data_final.' 23:59:59')
            ->where('user_id', Auth::id())
            ->get();

        $occurrenceTotal = 0;
        $occurrenceTotal = count($occurrences);

        $occurrencesByAssessment = Occurrence::where('created_at', '>=', $data_inicial.' 00:00:00')
            ->where('created_at', '<=',  $data_final.' 23:59:59')
            ->where('user_id', Auth::id())
            ->select('assessment', DB::raw('count(*) as total'))
            ->groupBy('assessment')
            ->get();

        return view('occurrences.myOccurrences', compact('occurrences', 'occurrencesByAssessment', 'occurrenceTotal' ,'date'));
    }

    public function home()
    {
        $occurrencesType = OccurrenceType::orderBy('occurrence_type')->get();
        $assessmentType = AssessmentType::orderBy('assessment_type')->get();
        $occurrenceLocal = OccurrenceLocal::orderBy('local')->get();
        return view('occurrences/home', compact('occurrencesType', 'assessmentType', 'occurrenceLocal'));
    }
    
    public function create()
    {
        $occurrencesType = OccurrenceType::orderBy('occurrence_type')->get();
        $assessmentType = AssessmentType::orderBy('assessment_type')->get();
        $occurrenceLocal = OccurrenceLocal::orderBy('local')->get();
        return view('occurrences/create', compact('occurrencesType', 'assessmentType', 'occurrenceLocal'));
    }

    public function store(Request $request)
    {
        $input = $request->all();
        $user = DB::table('users')->where('id', Auth::id())->first();
        $input['user'] = $user->name;
        $input['user_id'] = $user->id;
        $occurrenceId = Occurrence::create($input);

        if ($request->hasFile('imagem')) {
            foreach ($request->file('imagem') as $key => $file) {
                $fileName = '/bower_components/admin-lte/dist/img/occurrences/' . $occurrenceId->id . $file->getClientOriginalName();
                $file->move(public_path('bower_components/admin-lte/dist/img/occurrences'), $fileName);

                DB::table('images_occurrences')->insert([
                    'occurrence_id' => $occurrenceId->id,
                    'path' => URL::asset('/bower_components/admin-lte/dist/img/occurrences/' . $occurrenceId->id . $file->getClientOriginalName())
                    //'path' => 'https://seopitabuna.bizybox.com.br/public/images/occurrences/' .  $file->getClientOriginalName()
                ]);
            }
        }

        Session::flash('flash_message', 'Ocorrência cadastrada com sucesso!');
        return Redirect::to('occurrences/create');

    }

    public function involveds(Request $request)
    {
        $involveds = Occurrence::where('id', $request['occurrenceId'])->select('involveds')->first();
        return response()->json($involveds);
    }

    public function pictures(Request $request)
    {
        $pictures = DB::table('images_occurrences')->where('occurrence_id', $request['occurrenceId'])->get();
        return response()->json($pictures);
    }

    public function mobile()
    {
        return view('occurrences.mobile');
    }

    public function storeOccurrenceType(Request $request)
    {
        $input = $request->all();
        OccurrenceType::create($input);
        return \response()->json();
    }

    public function storeOccurrenceLocal(Request $request)
    {
        $input = $request->all();
        OccurrenceLocal::create($input);
        return \response()->json();
    }

    public function storeAssessmentType(Request $request)
    {
        $input = $request->all();
        AssessmentType::create($input);
        return \response()->json();
    }

    public function updateOccurrenceType(Request $request)
    {
        OccurrenceType::where('occurrence_type', $request->occurrence_type)->update(['occurrence_type' =>  $request->occurrence_type_new]);
        return \response()->json();
    }

    public function updateAssessmentType(Request $request)
    {
        AssessmentType::where('assessment_type', $request->assessment)->update(['assessment_type' =>  $request->assessment_new]);
        return \response()->json();
    }

}
