@extends('masterpage.masterpage')
<!-- Content Header (Page header) -->

@section ('content')
<section class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1>Combustível</h1>
        </div>
      </div>
    </div><!-- /.container-fluid -->
  </section>
  <!-- Main content -->
  <section class="content">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          @if(Session::has('flash_message'))
            <div class="alert alert-success alert-dismissible">
              <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
              <h5><i class="icon fas fa-check"></i> {{ Session::get('flash_message')}}</h5>
            </div>
          @endif
          @if(Session::has('error'))
            <div class="alert alert-danger alert-dismissible">
              <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
              <h5><i class="icon fas fa-ban"></i> {{ Session::get('error')}}</h5>
            </div>
          @endif
          <div class="card">
            <div class="card-header">
              <h3 class="card-title">Lista</h3>
           
            </div>
            <div class="card-header">
                <a style="margin-top: 10px" href="{{ URL('combustivel/create') }}" class="btn btn-primary">Nova liberação</a>
            </div>  
            <div class="card-body">            
              <table id="example1" class="table table-striped">
                <thead>                
                <tr>
                  <th>Controle</th>
                  <th>Liderança</th>
                  <th>Data</th>
                  <th>Valor</th>      
                  <th>Placa</th>      
                  <th style="text-align: right">Ações</th>
                </tr>
                </thead>
                <tbody>
                  @foreach ($combustiveis as $combustivel)
                  <tr>
                    <td>{{ $combustivel->id }}</td>
                    <td>{{ $combustivel->lider_name }}</td>
                    <td>{{ date("d/m/Y H:i", strtotime($combustivel->created_at)) }}</td>
                    <td>{{ number_format($combustivel->valor, 2, ',', '.') }}</td>             
                    <td>{{ $combustivel->placa }}</td>             
                    <td style="text-align: right">
                      <div>
                        <a href="{{ URL('combustivel/edit/'. $combustivel->id) }}" class="btn btn-primary btn rounded-circle"
                          title="Editar"><i class="fa fa-edit"></i>
                        </a>
                        <a href="{{ URL('combustivel/print/'. $combustivel->id) }}"" class="btn btn-warning btn rounded-circle"
                          title="Imprirmir comprovante" target="_blank"><i class="fa fa-print"></i>
                        </a>
                        <a href="#" onclick="confirmDelete(this)" combustivelId="{{ $combustivel->id }}" class="btn btn-danger btn rounded-circle"
                          title="Excluir"><i class="fa fa-trash"></i>
                        </a>
                      </div>  
                    </td>
                  </tr>   
                @endforeach
                </tbody> 
                </tfoot>
              </table>
              <a style="margin-top: 10px" href="{{ URL('combustivel/create') }}" class="btn btn-primary">Nova liberação</a>
            </div>
          </div>
        </div>
      </div>
    </div>
    <input type="hidden" name="_token" id="csrf-token" value="{{ Session::token() }}" />
    
  </section>

  @stop

 @section('scripts')

  <script>

    $(function () {
      $("#example1").DataTable({
          "responsive": true,
          "autoWidth": false,
          "oLanguage":{
            "sEmptyTable": "Nenhum registro encontrado",
            "sInfo": "Mostrando de _START_ até _END_ de _TOTAL_ registros",
            "sInfoEmpty": "Mostrando 0 até 0 de 0 registros",
            "sInfoFiltered": "(Filtrados de _MAX_ registros)",
            "sInfoPostFix": "",
            "sInfoThousands": ".",
            "sLengthMenu": "_MENU_ Resultados por página",
            "sLoadingRecords": "Carregando...",
            "sProcessing": "Processando...",
            "sZeroRecords": "Nenhum registro encontrado",
            "sSearch": "Pesquisar ",
            "oPaginate": {
                  "sNext": "Próximo",
                  "sPrevious": "Anterior",
                  "sFirst": "Primeiro",
                  "sLast": "Último"
            }
          }
      }).buttons().container().appendTo('#example1_wrapper .col-md-6:eq(0)');
    });

    function confirmDelete(params) {
      Swal.fire({
        title: 'Tem certeza que deseja excluir?',
        text: "Os dados serão excluídos permanentemente!",
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: 'Confirmar',
        cancelButtonText: 'Cancelar',
      }).then((result) => {
        if (result.isConfirmed) {
          var csrfToken = document.getElementById('csrf-token').value;
          var data = new FormData();
          data.append('combustivelId', params.getAttribute('combustivelId'));      
          fetch('{{URL('combustivel/destroy')}}', {
            method: 'post',
            body: data,
            headers: {
              "X-CSRF-Token": csrfToken
            },       
          }).then(function(response) {
            if (response.status === 200) {
              Swal.fire({
                icon: 'success',
                title: 'Liberação excluída com sucesso',
                showConfirmButton: false,
                timer: 1500
              })
              window.location.reload();
            } else {
              Swal.fire(
                'Falha!',
                'Falha ao excluir liberação.',
                'error'
              )
            }
          });
        }
      })
    }

    $(document).ready(function(){
      window.frames["print_frame"].document.body.innerHTML = document.getElementById("printer").innerHTML;
      window.frames["print_frame"].window.focus();
      window.frames["print_frame"].window.print();
    });

  </script>
 @stop