@extends('masterpage.masterpage')

@section ('content')
<section class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1>Despesas</h1>
        </div>
      </div>
    </div>
  </section>

  <section class="content">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          @if(Session::has('flash_message'))
            <div class="alert alert-success alert-dismissible">
              <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
              <h5><i class="icon fas fa-check"></i> {{ Session::get('flash_message')}}</h5>
            </div>
          @endif
          @if(Session::has('error'))
            <div class="alert alert-danger alert-dismissible">
              <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
              <h5><i class="icon fas fa-ban"></i> {{ Session::get('error')}}</h5>
            </div>
          @endif
          <div class="card">
            <div class="card-header">
              <h3 class="card-title"><b><i>Lista</b></i></h3>
           
            </div>
            <div class="card-header">
                <a style="margin-top: 10px" href="{{ URL('despesas/create') }}" class="btn btn-primary">Novo despesa</a>
            </div>  
            <div class="card-body">            
              <table id="example1" class="table table-striped">
                <thead>                
                <tr>
                  <th>Data</th>
                  <th>Grupo</th>
                  <th>Descrição</th>
                  <th>Valor</th>
                  <th>Responsável</th>
                  <th style="text-align: right">Ações</th>
                </tr>
                </thead>
                <tbody>
                  @foreach ($despesas as $despesa)
                  <tr>
                    <td>{{ date("d/m/Y", strtotime($despesa->data)) }}</td>
                    <td>{{ $despesa->grupo->nome }}</td>
                    <td>{{ $despesa->descricao }}</td>
                    <td>{{ number_format($despesa->valor, '2', ',', '.') }}</td>
                    <td>{{ $despesa->responsavel }}</td>
                    <td style="text-align: right">
                      <div>
                        <a href="{{ URL('despesas/edit/'. $despesa->id) }}" class="btn btn-primary btn rounded-circle"
                          title="Editar"><i class="fa fa-edit"></i>
                        </a>
                        <a href="#" onclick="confirmDelete(this)" despesaId="{{ $despesa->id }}" class="btn btn-danger btn rounded-circle"
                            title="Excluir"><i class="fa fa-trash"></i>
                        </a>
                      </div>  
                    </td>
                  </tr>   
                @endforeach
                </tbody> 
                </tfoot>
              </table>
              <a style="margin-top: 10px" href="{{ URL('despesas/create') }}" class="btn btn-primary">Novo despesa</a>
            </div>
          </div>
        </div>
      </div>
    </div>
    <input type="hidden" name="_token" id="csrf-token" value="{{ Session::token() }}" />
    
  </section>

  @stop

 @section('scripts')

  <script>

    $(function () {
      $("#example1").DataTable({
          "responsive": true,
          "autoWidth": false,
          "oLanguage":{
            "sEmptyTable": "Nenhum registro encontrado",
            "sInfo": "Mostrando de _START_ até _END_ de _TOTAL_ registros",
            "sInfoEmpty": "Mostrando 0 até 0 de 0 registros",
            "sInfoFiltered": "(Filtrados de _MAX_ registros)",
            "sInfoPostFix": "",
            "sInfoThousands": ".",
            "sLengthMenu": "_MENU_ Resultados por página",
            "sLoadingRecords": "Carregando...",
            "sProcessing": "Processando...",
            "sZeroRecords": "Nenhum registro encontrado",
            "sSearch": "Pesquisar ",
            "oPaginate": {
                  "sNext": "Próximo",
                  "sPrevious": "Anterior",
                  "sFirst": "Primeiro",
                  "sLast": "Último"
            }
          }
      }).buttons().container().appendTo('#example1_wrapper .col-md-6:eq(0)');
    })

    function confirmDelete(params) {
      Swal.fire({
        title: 'Tem certeza que deseja excluir?',
        text: "Os dados serão excluídos permanentemente!",
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: 'Confirmar',
        cancelButtonText: 'Cancelar',
      }).then((result) => {
        if (result.isConfirmed) {
          var csrfToken = document.getElementById('csrf-token').value;
          var data = new FormData();
          data.append('despesaId', params.getAttribute('despesaId'));      
          fetch('{{URL('despesas/destroy')}}', {
            method: 'post',
            body: data,
            headers: {
              "X-CSRF-Token": csrfToken
            },       
          }).then(function(response) {
            if (response.status === 200) {
              Swal.fire({
                icon: 'success',
                title: 'Cadastro excluído com sucesso',
                showConfirmButton: false,
                timer: 1500
              })
              window.location.reload();
            } else {
              Swal.fire(
                'Falha!',
                'Falha ao excluir despesa.',
                'error'
              )
            }
          });
        }
      })
    }

    </script>
 @stop